package com.ruoyi.web.plotmanage.service.impl;

import java.util.List;

import com.ruoyi.web.plotmanage.domain.AdFlat;
import com.ruoyi.web.plotmanage.mapper.AdFlatMapper;
import com.ruoyi.web.plotmanage.service.IAdFlatService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;


/**
 * 楼宇管理Service业务层处理
 * 
 * @author cyx
 * @date 2022-11-24
 */
@Service
public class AdFlatServiceImpl implements IAdFlatService
{
    @Autowired
    private AdFlatMapper adFlatMapper;

    /**
     * 查询楼宇管理
     * 
     * @param id 楼宇管理主键
     * @return 楼宇管理
     */
    @Override
    public AdFlat selectAdFlatById(String id)
    {
        return adFlatMapper.selectAdFlatById(id);
    }

    /**
     * 查询楼宇管理列表
     * 
     * @param adFlat 楼宇管理
     * @return 楼宇管理
     */
    @Override
    public List<AdFlat> selectAdFlatList(AdFlat adFlat)
    {
        return adFlatMapper.selectAdFlatList(adFlat);
    }

    /**
     * 新增楼宇管理
     * 
     * @param adFlat 楼宇管理
     * @return 结果
     */
    @Override
    public int insertAdFlat(AdFlat adFlat)
    {
        return adFlatMapper.insertAdFlat(adFlat);
    }

    /**
     * 修改楼宇管理
     * 
     * @param adFlat 楼宇管理
     * @return 结果
     */
    @Override
    public int updateAdFlat(AdFlat adFlat)
    {
        return adFlatMapper.updateAdFlat(adFlat);
    }

    /**
     * 批量删除楼宇管理
     * 
     * @param ids 需要删除的楼宇管理主键
     * @return 结果
     */
    @Override
    public int deleteAdFlatByIds(String[] ids)
    {
        return adFlatMapper.deleteAdFlatByIds(ids);
    }

    /**
     * 删除楼宇管理信息
     * 
     * @param id 楼宇管理主键
     * @return 结果
     */
    @Override
    public int deleteAdFlatById(String id)
    {
        return adFlatMapper.deleteAdFlatById(id);
    }
}
