package com.ruoyi.web.controller.plotmanage;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.web.plotmanage.domain.AdFlat;
import com.ruoyi.web.plotmanage.service.IAdFlatService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 楼宇管理Controller
 * 
 * @author cyx
 * @date 2022-11-24
 */
@Api("楼宇管理")
@RestController
@RequestMapping("/plotmanage/flat")
public class AdFlatController extends BaseController
{
    @Autowired
    private IAdFlatService adFlatService;

    /**
     * 查询楼宇管理列表
     */
    @ApiOperation("查询楼宇管理列表")
    @PreAuthorize("@ss.hasPermi('plotmanage:flat:list')")
    @GetMapping("/list")
    public TableDataInfo list(AdFlat adFlat)
    {
        startPage();
        List<AdFlat> list = adFlatService.selectAdFlatList(adFlat);
        return getDataTable(list);
    }

    /**
     * 导出楼宇管理列表
     */
    @ApiOperation("导出楼宇列表")
    @PreAuthorize("@ss.hasPermi('plotmanage:flat:export')")
    @Log(title = "楼宇管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AdFlat adFlat)
    {
        List<AdFlat> list = adFlatService.selectAdFlatList(adFlat);
        ExcelUtil<AdFlat> util = new ExcelUtil<AdFlat>(AdFlat.class);
        util.exportExcel(response, list, "楼宇管理数据");
    }

    /**
     * 获取楼宇管理详细信息
     */
    @ApiOperation("获取楼宇管理详细信息")
    @PreAuthorize("@ss.hasPermi('plotmanage:flat:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return AjaxResult.success(adFlatService.selectAdFlatById(id));
    }

    /**
     * 新增楼宇管理
     */
    @ApiOperation("新增楼宇管理")
    @PreAuthorize("@ss.hasPermi('plotmanage:flat:add')")
    @Log(title = "楼宇管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AdFlat adFlat)
    {
        return toAjax(adFlatService.insertAdFlat(adFlat));
    }

    /**
     * 修改楼宇管理
     */
    @ApiOperation("修改楼宇管理")
    @PreAuthorize("@ss.hasPermi('plotmanage:flat:edit')")
    @Log(title = "楼宇管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AdFlat adFlat)
    {
        return toAjax(adFlatService.updateAdFlat(adFlat));
    }

    /**
     * 删除楼宇管理
     */
    @ApiOperation("删除楼宇管理")
    @PreAuthorize("@ss.hasPermi('plotmanage:flat:remove')")
    @Log(title = "楼宇管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(adFlatService.deleteAdFlatByIds(ids));
    }
}
